summaryrefslogtreecommitdiffstats
path: root/src/entryitem.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-02 06:40:27 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-02 06:40:27 +0000
commit2595a15ebeb6fc46b7cb241d01ec0c2460ec2111 (patch)
tree18a8f0f4ac5a86dacfa74c3537551ec39bc85e75 /src/entryitem.h
parent1d90725a4001fab9d3922b2cbcceeee5e2d1686f (diff)
downloadtellico-2595a15ebeb6fc46b7cb241d01ec0c2460ec2111.tar.gz
tellico-2595a15ebeb6fc46b7cb241d01ec0c2460ec2111.zip
TQt4 port tellico
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/tellico@1239054 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/entryitem.h')
-rw-r--r--src/entryitem.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/entryitem.h b/src/entryitem.h
index 4e529c8..d0063c9 100644
--- a/src/entryitem.h
+++ b/src/entryitem.h
@@ -34,22 +34,22 @@ namespace Tellico {
class EntryItem : public GUI::ListViewItem {
public:
/**
- * This constructor is for items which are direct children of a ListView object,
+ * This constructor is for items which are direct tqchildren of a ListView object,
* which is just the @ref DetailedListView.
*
* @param parent A pointer to the parent
* @param entry A pointer to the entry to which the item refers
*/
- EntryItem(GUI::ListView* parent, Data::EntryPtr entry);
+ EntryItem(GUI::ListView* tqparent, Data::EntryPtr entry);
/**
- * This constructor is for items which have other KListViewItems as parents. It
+ * This constructor is for items which have other KListViewItems as tqparents. It
* initializes the text in the first column, as well.
*
* @param parent A pointer to the parent
* @param text The text in the first column
* @param entry A pointer to the entry to which the item refers
*/
- EntryItem(GUI::CountedItem* parent, Data::EntryPtr entry);
+ EntryItem(GUI::CountedItem* tqparent, Data::EntryPtr entry);
virtual bool isEntryItem() const { return true; }
@@ -60,7 +60,7 @@ public:
* @param col Column to compare
* @return The key string
*/
- virtual QString key(int col, bool) const;
+ virtual TQString key(int col, bool) const;
/**
* Returns a const pointer to the entry to which the item refers
*
@@ -73,7 +73,7 @@ public:
private:
Data::EntryPtr m_entry;
- // if the parent is a DetailedListView
+ // if the tqparent is a DetailedListView
// this way, I don't have to call listView()->isA("Tellico::DetailedListView") every time
// when I want to do funky comparisons
bool m_isDetailedList : 1;
@@ -34,22 +34,22 @@ namespace Tellico {
* which is just the @ref DetailedListView.
*
- * @param parent A pointer to the parent
+ * @param tqparent A pointer to the tqparent
* @param entry A pointer to the entry to which the item refers
*/
@@ -34,22 +34,22 @@ namespace Tellico {
* initializes the text in the first column, as well.
*
- * @param parent A pointer to the parent
+ * @param tqparent A pointer to the tqparent
* @param text The text in the first column
* @param entry A pointer to the entry to which the item refers